# ATLS API Client
AT-RTS (Remote Translation Service) is the web API which enables our translation systems to be integrated into our clients’ systems, from where the entire content translation process can be controlled.<br/>The web API, based on a SOAP web service, has REST interoperability from version 5.3.0.<br/>The operational functionalities are:<ul><li><b>Operating check:</b> Active service check.</li><li><b>Synchronous translation:</b> requests for automatic translation (non-human) orders.</li><li><b>Asynchronous translation:</b> Asynchronous requests for specialised professional translation orders.<br/>Each request returns a <b><i>token</i></b>, associated with the translation request, the purpose of which is to uniquely identify each work request so that the corresponding translation can be requested in the future once proofreading is complete.<br/>It should be noted that asynchronous translation requests have the option to indicate a <b><i>callback</i></b> URL, which involves activating a completed translation notification service, so that our clients can automate the completed request download process.<br/>To summarise, in this case, AT sends the requests directly to our clients’ systems for them to be located in their systems.<br/>Conceptually, at ATLS Global we guarantee the <b><i>return of translations</i></b> for asynchronous order requests to our clients’ infrastructure, taking into account that if the communication system fails <b><i>repeatedly a certain number of times</i></b> for any reason, a warning email would be sent to the email account that the client has specified during the request.</li><li><b>Translation return request:</b> Request to obtain a professional translation order from a token generated by the asynchronous translation request. If the order is not complete, it returns document status information.</li><li><b>Cancellation of a translation:</b> request for cancellation of previous asynchronous translation requests by token that have not been initiated. In this case, ATLS Global S.L. systems will validate that the indicated token has not started the translation process; if it has not started, the request will be cancelled.</li><li><b>List of requests:</b> Request regarding status and consumption of translation orders from the cut-off date, with the following information:<ul><li>projectid: AT project ID</li><li>token: Request token</li><li>sourcelang: Source language</li><li>targetlang: Target language</li>filename: Name associated with the request</li><li>wordcount: Number of words</li><li>status: Translation status<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Canceled and deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li></ul></li><li>urlcallback: (optional) completed translation return URL</li><li>errnotifiersendto (optional): translation return error notification email</li><li>dateinsert: Date of registration</li><li>type: Translation type, SYNCHRONOUS OR ASYNCHRONOUS.</li></ul></li></ul>

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 5.6.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import atls_api 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import atls_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import atls_api
from atls_api.rest import ApiException
from pprint import pprint

# Configure API key authorization: ApiKeyAuth
configuration = atls_api.Configuration()
configuration.api_key['X-ATRTS-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-ATRTS-API-Key'] = 'Bearer'# Configure HTTP basic authorization: BasicAuth
configuration = atls_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))
body = NULL # object | Document information to be deleted

try:
    # delFileByToken
    api_response = api_instance.del_file_by_token(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->del_file_by_token: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = atls_api.Configuration()
configuration.api_key['X-ATRTS-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-ATRTS-API-Key'] = 'Bearer'# Configure HTTP basic authorization: BasicAuth
configuration = atls_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))
body = NULL # object | Example of a revised file request

try:
    # getFileByToken
    api_response = api_instance.get_file_by_token(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->get_file_by_token: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = atls_api.Configuration()
configuration.api_key['X-ATRTS-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-ATRTS-API-Key'] = 'Bearer'# Configure HTTP basic authorization: BasicAuth
configuration = atls_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))
projectid = 56 # int | Translation project identifier.
sourcelang = 'sourcelang_example' # str | Source language code in ISO-639-3 format.
targetlang = 'targetlang_example' # str | Target language code in ISO-639-3 format.
datecutoff = 'datecutoff_example' # str | Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).
options = 'options_example' # str | JSON auxiliary options. (optional)

try:
    # getList
    api_response = api_instance.get_list(projectid, sourcelang, targetlang, datecutoff, options=options)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->get_list: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = atls_api.Configuration()
configuration.api_key['X-ATRTS-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-ATRTS-API-Key'] = 'Bearer'# Configure HTTP basic authorization: BasicAuth
configuration = atls_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))
projectid = 56 # int | Translation project identifier.
token = 'token_example' # str | Token resulting from the asynchronous translation request.
options = 'options_example' # str | JSON auxiliary options. (optional)

try:
    # getFileByToken
    api_response = api_instance.getget_file_by_token(projectid, token, options=options)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->getget_file_by_token: %s\n" % e)

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))

try:
    # ping
    api_response = api_instance.ping()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->ping: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = atls_api.Configuration()
configuration.api_key['X-ATRTS-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-ATRTS-API-Key'] = 'Bearer'# Configure HTTP basic authorization: BasicAuth
configuration = atls_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))
body = NULL # object | Example of a revised translation

try:
    # translateAsynchronous
    api_response = api_instance.translate_asynchronous(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->translate_asynchronous: %s\n" % e)

# Configure API key authorization: ApiKeyAuth
configuration = atls_api.Configuration()
configuration.api_key['X-ATRTS-API-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-ATRTS-API-Key'] = 'Bearer'# Configure HTTP basic authorization: BasicAuth
configuration = atls_api.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = atls_api.RestapiApi(atls_api.ApiClient(configuration))
body = NULL # object | Example of synchronous machine translation

try:
    # translateSynchronous
    api_response = api_instance.translate_synchronous(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling RestapiApi->translate_synchronous: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://rts.at-ls.com/atrts*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*RestapiApi* | [**del_file_by_token**](docs/RestapiApi.md#del_file_by_token) | **POST** /delFileByToken | delFileByToken
*RestapiApi* | [**get_file_by_token**](docs/RestapiApi.md#get_file_by_token) | **POST** /getFileByToken | getFileByToken
*RestapiApi* | [**get_list**](docs/RestapiApi.md#get_list) | **GET** /getList | getList
*RestapiApi* | [**getget_file_by_token**](docs/RestapiApi.md#getget_file_by_token) | **GET** /getFileByToken | getFileByToken
*RestapiApi* | [**ping**](docs/RestapiApi.md#ping) | **GET** /ping | ping
*RestapiApi* | [**translate_asynchronous**](docs/RestapiApi.md#translate_asynchronous) | **POST** /translateAsynchronous | translateAsynchronous
*RestapiApi* | [**translate_synchronous**](docs/RestapiApi.md#translate_synchronous) | **POST** /translateSynchronous | translateSynchronous

## Documentation For Models

 - [ErrorResponse](docs/ErrorResponse.md)
 - [File](docs/File.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse401](docs/InlineResponse401.md)
 - [InlineResponse405](docs/InlineResponse405.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [OutFile](docs/OutFile.md)
 - [OutList](docs/OutList.md)
 - [OutToken](docs/OutToken.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-ATRTS-API-Key
- **Location**: HTTP header

## BasicAuth

- **Type**: HTTP basic authentication


## Author

info@at-ls.com
