# coding: utf-8

"""
    AT-RTS

    AT-RTS (Remote Translation Service) is the web API which enables our translation systems to be integrated into our clients’ systems, from where the entire content translation process can be controlled.<br/>The web API, based on a SOAP web service, has REST interoperability from version 5.3.0.<br/>The operational functionalities are:<ul><li><b>Operating check:</b> Active service check.</li><li><b>Synchronous translation:</b> requests for automatic translation (non-human) orders.</li><li><b>Asynchronous translation:</b> Asynchronous requests for specialised professional translation orders.<br/>Each request returns a <b><i>token</i></b>, associated with the translation request, the purpose of which is to uniquely identify each work request so that the corresponding translation can be requested in the future once proofreading is complete.<br/>It should be noted that asynchronous translation requests have the option to indicate a <b><i>callback</i></b> URL, which involves activating a completed translation notification service, so that our clients can automate the completed request download process.<br/>To summarise, in this case, AT sends the requests directly to our clients’ systems for them to be located in their systems.<br/>Conceptually, at ATLS Global we guarantee the <b><i>return of translations</i></b> for asynchronous order requests to our clients’ infrastructure, taking into account that if the communication system fails <b><i>repeatedly a certain number of times</i></b> for any reason, a warning email would be sent to the email account that the client has specified during the request.</li><li><b>Translation return request:</b> Request to obtain a professional translation order from a token generated by the asynchronous translation request. If the order is not complete, it returns document status information.</li><li><b>Cancellation of a translation:</b> request for cancellation of previous asynchronous translation requests by token that have not been initiated. In this case, ATLS Global S.L. systems will validate that the indicated token has not started the translation process; if it has not started, the request will be cancelled.</li><li><b>List of requests:</b> Request regarding status and consumption of translation orders from the cut-off date, with the following information:<ul><li>projectid: AT project ID</li><li>token: Request token</li><li>sourcelang: Source language</li><li>targetlang: Target language</li>filename: Name associated with the request</li><li>wordcount: Number of words</li><li>status: Translation status<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Canceled and deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li></ul></li><li>urlcallback: (optional) completed translation return URL</li><li>errnotifiersendto (optional): translation return error notification email</li><li>dateinsert: Date of registration</li><li>type: Translation type, SYNCHRONOUS OR ASYNCHRONOUS.</li></ul></li></ul>  # noqa: E501

    OpenAPI spec version: 5.6.0
    Contact: info@at-ls.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from atls_api.api_client import ApiClient


class RestapiApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def del_file_by_token(self, body, **kwargs):  # noqa: E501
        """delFileByToken  # noqa: E501

        Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the <b>status</b> of the translation. Possible values for asynchronous translations are:<ul><li>10: Under review</li><li>20: Ready and to be delivered</li><li>30: Delivered</li><li>40: Deleted</li><li>50: Delivery expired</li><li>90: Document entry error</li><li>100: Processing error</li><ul>The <b>filename</b> key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.del_file_by_token(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Document information to be deleted (required)
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.del_file_by_token_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.del_file_by_token_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def del_file_by_token_with_http_info(self, body, **kwargs):  # noqa: E501
        """delFileByToken  # noqa: E501

        Method exclusively designed to cancel an asynchronous translation request via a unique token (generated in the asynchronous translation request). A request can only be cancelled if it has not started to be processed. The status key indicates the <b>status</b> of the translation. Possible values for asynchronous translations are:<ul><li>10: Under review</li><li>20: Ready and to be delivered</li><li>30: Delivered</li><li>40: Deleted</li><li>50: Delivery expired</li><li>90: Document entry error</li><li>100: Processing error</li><ul>The <b>filename</b> key indicates the name of the file, the base64 key indicates the content of the file in base64 if the request is in status 30 (delivered) and the wordcount key indicates the number of words in the file translated. If the document has already been deleted, the errorCode field shall contain the value 404. If the document cannot be deleted because the translation has already been started, the errorCode field will contain the value 403.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.del_file_by_token_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Document information to be deleted (required)
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method del_file_by_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `del_file_by_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'BasicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/delFileByToken', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutFile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file_by_token(self, body, **kwargs):  # noqa: E501
        """getFileByToken  # noqa: E501

        Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are:<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li><ul>The <b>filename</b> key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_by_token(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Example of a revised file request (required)
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_file_by_token_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.get_file_by_token_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def get_file_by_token_with_http_info(self, body, **kwargs):  # noqa: E501
        """getFileByToken  # noqa: E501

        Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). The status key indicates the translation status. The possible values for asynchronous translations are:<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li><ul>The <b>filename</b> key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_by_token_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Example of a revised file request (required)
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file_by_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `get_file_by_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'BasicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/getFileByToken', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutFile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_list(self, projectid, sourcelang, targetlang, datecutoff, **kwargs):  # noqa: E501
        """getList  # noqa: E501

        Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list(projectid, sourcelang, targetlang, datecutoff, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int projectid: Translation project identifier. (required)
        :param str sourcelang: Source language code in ISO-639-3 format. (required)
        :param str targetlang: Target language code in ISO-639-3 format. (required)
        :param str datecutoff: Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time). (required)
        :param str options: JSON auxiliary options.
        :return: OutList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_list_with_http_info(projectid, sourcelang, targetlang, datecutoff, **kwargs)  # noqa: E501
        else:
            (data) = self.get_list_with_http_info(projectid, sourcelang, targetlang, datecutoff, **kwargs)  # noqa: E501
            return data

    def get_list_with_http_info(self, projectid, sourcelang, targetlang, datecutoff, **kwargs):  # noqa: E501
        """getList  # noqa: E501

        Request designed to check the status of all requested translation requests, whether synchronous or asynchronous. The results can be filtered using the date of sending the translation order requests, in Zulu format.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_list_with_http_info(projectid, sourcelang, targetlang, datecutoff, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int projectid: Translation project identifier. (required)
        :param str sourcelang: Source language code in ISO-639-3 format. (required)
        :param str targetlang: Target language code in ISO-639-3 format. (required)
        :param str datecutoff: Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time). (required)
        :param str options: JSON auxiliary options.
        :return: OutList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['projectid', 'sourcelang', 'targetlang', 'datecutoff', 'options']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'projectid' is set
        if ('projectid' not in params or
                params['projectid'] is None):
            raise ValueError("Missing the required parameter `projectid` when calling `get_list`")  # noqa: E501
        # verify the required parameter 'sourcelang' is set
        if ('sourcelang' not in params or
                params['sourcelang'] is None):
            raise ValueError("Missing the required parameter `sourcelang` when calling `get_list`")  # noqa: E501
        # verify the required parameter 'targetlang' is set
        if ('targetlang' not in params or
                params['targetlang'] is None):
            raise ValueError("Missing the required parameter `targetlang` when calling `get_list`")  # noqa: E501
        # verify the required parameter 'datecutoff' is set
        if ('datecutoff' not in params or
                params['datecutoff'] is None):
            raise ValueError("Missing the required parameter `datecutoff` when calling `get_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'projectid' in params:
            query_params.append(('projectid', params['projectid']))  # noqa: E501
        if 'sourcelang' in params:
            query_params.append(('sourcelang', params['sourcelang']))  # noqa: E501
        if 'targetlang' in params:
            query_params.append(('targetlang', params['targetlang']))  # noqa: E501
        if 'datecutoff' in params:
            query_params.append(('datecutoff', params['datecutoff']))  # noqa: E501
        if 'options' in params:
            query_params.append(('options', params['options']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'BasicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/getList', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def getget_file_by_token(self, projectid, token, **kwargs):  # noqa: E501
        """getFileByToken  # noqa: E501

        Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are:<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li><ul>The <b>filename</b> key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.getget_file_by_token(projectid, token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int projectid: Translation project identifier. (required)
        :param str token: Token resulting from the asynchronous translation request. (required)
        :param str options: JSON auxiliary options.
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.getget_file_by_token_with_http_info(projectid, token, **kwargs)  # noqa: E501
        else:
            (data) = self.getget_file_by_token_with_http_info(projectid, token, **kwargs)  # noqa: E501
            return data

    def getget_file_by_token_with_http_info(self, projectid, token, **kwargs):  # noqa: E501
        """getFileByToken  # noqa: E501

        Method designed exclusively to request the result of asynchronous translation requests through a unique token (generated in the asynchronous translation request). To ensure that the operation of this method is correct in the event of a GET type request, the token must be encoded in URL format. The status key indicates the translation status. The possible values for asynchronous translations are:<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li><ul>The <b>filename</b> key indicates the name, the base64 key indicates the file content in base64 if the request is in status 30 (delivered), and the wordcount key indicates the number of translated words in the file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.getget_file_by_token_with_http_info(projectid, token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int projectid: Translation project identifier. (required)
        :param str token: Token resulting from the asynchronous translation request. (required)
        :param str options: JSON auxiliary options.
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['projectid', 'token', 'options']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method getget_file_by_token" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'projectid' is set
        if ('projectid' not in params or
                params['projectid'] is None):
            raise ValueError("Missing the required parameter `projectid` when calling `getget_file_by_token`")  # noqa: E501
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `getget_file_by_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'projectid' in params:
            query_params.append(('projectid', params['projectid']))  # noqa: E501
        if 'token' in params:
            query_params.append(('token', params['token']))  # noqa: E501
        if 'options' in params:
            query_params.append(('options', params['options']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'BasicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/getFileByToken', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutFile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ping(self, **kwargs):  # noqa: E501
        """ping  # noqa: E501

        Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ping(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.ping_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.ping_with_http_info(**kwargs)  # noqa: E501
            return data

    def ping_with_http_info(self, **kwargs):  # noqa: E501
        """ping  # noqa: E501

        Checking that the service is working properly. This method does NOT REQUIRE AUTHENTICATION.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ping_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ping" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ping', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translate_asynchronous(self, body, **kwargs):  # noqa: E501
        """translateAsynchronous  # noqa: E501

        An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_asynchronous(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Example of a revised translation (required)
        :return: OutToken
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.translate_asynchronous_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.translate_asynchronous_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def translate_asynchronous_with_http_info(self, body, **kwargs):  # noqa: E501
        """translateAsynchronous  # noqa: E501

        An asynchronous translation request is generated, i.e. a review of a translation completed by a professional from the ATLS Global S.L. LSP division.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_asynchronous_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Example of a revised translation (required)
        :return: OutToken
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translate_asynchronous" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `translate_asynchronous`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'BasicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/translateAsynchronous', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutToken',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def translate_synchronous(self, body, **kwargs):  # noqa: E501
        """translateSynchronous  # noqa: E501

        Synchronous (non-human automatic translation) translation order request.  After the request, the service returns the file translated into the specified target language.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_synchronous(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Example of synchronous machine translation (required)
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.translate_synchronous_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.translate_synchronous_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def translate_synchronous_with_http_info(self, body, **kwargs):  # noqa: E501
        """translateSynchronous  # noqa: E501

        Synchronous (non-human automatic translation) translation order request.  After the request, the service returns the file translated into the specified target language.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.translate_synchronous_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: Example of synchronous machine translation (required)
        :return: OutFile
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method translate_synchronous" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `translate_synchronous`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['ApiKeyAuth', 'BasicAuth']  # noqa: E501

        return self.api_client.call_api(
            '/translateSynchronous', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OutFile',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
